import { signal, computed, inject, Injector, makeEnvironmentProviders, ENVIRONMENT_INITIALIZER } from '@angular/core';
import { setupListeners } from '@reduxjs/toolkit/query';
import { shallowEqual } from 'ngrx-rtk-query/core';

const createNoopStoreApi = (api, { injector = inject(Injector) } = {}) => {
    const reducerPath = api.reducerPath;
    const reducer = api.reducer;
    const state = signal({});
    return () => {
        const getState = computed(() => ({ [reducerPath]: state() }));
        const dispatch = (action) => {
            state.set(reducer(state(), action));
            return action;
        };
        const useSelector = (mapFn, options) => computed(() => mapFn(getState()), { equal: options?.equal });
        const hooks = { dispatch: dispatch, getState, useSelector };
        const createSelector = (...input) => {
            return computed(() => input.reduce((acc, selector) => selector(acc), getState()), { equal: shallowEqual });
        };
        const getInjector = () => injector;
        return { hooks, createSelector, getInjector };
    };
};
function provideNoopStoreApi(api, { setupListeners: setupListeners$1 } = {}) {
    setupListeners$1 === false ? undefined : setupListeners(api.dispatch, setupListeners$1);
    return makeEnvironmentProviders([
        {
            provide: ENVIRONMENT_INITIALIZER,
            multi: true,
            useValue() {
                api.initApiStore(createNoopStoreApi(api));
            },
        },
    ]);
}

/**
 * Generated bundle index. Do not edit.
 */

export { provideNoopStoreApi };
//# sourceMappingURL=ngrx-rtk-query-noop-store.mjs.map
